/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.gdpr.dataexport.provider.mail.generator;

import java.util.Optional;
import com.openexchange.gdpr.dataexport.GeneratedSession;

/**
 * {@link FailedAuthenticationResult} - The result of examined failed authentication.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.3
 */
public class FailedAuthenticationResult {

    private final Optional<GeneratedSession> optionalSession;

    /**
     * Initializes a new {@link FailedAuthenticationResult}.
     */
    public FailedAuthenticationResult() {
        this(null);
    }

    /**
     * Initializes a new {@link FailedAuthenticationResult}.
     */
    public FailedAuthenticationResult(GeneratedSession session) {
        super();
        this.optionalSession = Optional.ofNullable(session);
    }

    /**
     * Gets the optional session to retry with.
     *
     * @return The optional session
     */
    public Optional<GeneratedSession> getOptionalSession() {
        return optionalSession;
    }

    /**
     * Whether to retry or not.
     *
     * @return <code>true</code> to retry; otherwise <code>false</code>
     */
    public boolean retry() {
        return optionalSession.isPresent();
    }

}
